coreext

package
v0.0.0-...-8ef638e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 14, 2014 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Register

func Register(e *core.Extensions)

Types

type Die

type Die struct{}

Die is a core extension of gopherbot that illustrates a simple use of the gopherbot extension system.

Commands:

die - haha person in chat who is sick of gopherbot

func (Die) Commands

func (b Die) Commands() []string

func (Die) Process

func (b Die) Process(con *irc.Connection, channel string, user string, args []string)

Jump to